==> allure-report-data-1.3.6-sources.jar: ru/yandex/qatools/allure/data/DefectItem.java <==

package ru.yandex.qatools.allure.data;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlType;
import ru.yandex.qatools.allure.model.Failure;


/**
 * <p>Java class for defect-item complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="defect-item">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;all>
 *         &lt;element name="failure" type="{urn:data.allure.qatools.yandex.ru}failure"/>
 *         &lt;element name="test-cases" type="{urn:data.allure.qatools.yandex.ru}allure-test-cases-info"/>
 *       &lt;/all>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "defect-item", propOrder = {

})
public class DefectItem {

    @XmlElement(required = true)
    protected Failure failure;
    @XmlElementWrapper(name = "test-cases", required = true)
    @XmlElement(name = "test-case")
    protected List<AllureTestCaseInfo> testCases;

    /**
     * Gets the value of the failure property.
     * 
     * @return
     *     possible object is
     *     {@link Failure }
     *     
     */
    public Failure getFailure() {
        return failure;
    }

    /**
     * Sets the value of the failure property.
     * 
     * @param value
     *     allowed object is
     *     {@link Failure }
     *     
     */
    public void setFailure(Failure value) {
        this.failure = value;
    }

    public List<AllureTestCaseInfo> getTestCases() {
        if (testCases == null) {
            testCases = new ArrayList<AllureTestCaseInfo>();
        }
        return testCases;
    }

    public void setTestCases(List<AllureTestCaseInfo> testCases) {
        this.testCases = testCases;
    }

}

==> allure-report-data-1.4.7-sources.jar: ru/yandex/qatools/allure/data/DefectItem.java <==

package ru.yandex.qatools.allure.data;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlType;
import ru.yandex.qatools.allure.model.Failure;


/**
 * <p>Java class for defect-item complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="defect-item">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;all>
 *         &lt;element name="uid" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="failure" type="{urn:data.allure.qatools.yandex.ru}failure"/>
 *         &lt;element name="test-cases" type="{urn:data.allure.qatools.yandex.ru}allure-test-cases-info"/>
 *       &lt;/all>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "defect-item", propOrder = {

})
public class DefectItem {

    @XmlElement(required = true)
    protected String uid;
    @XmlElement(required = true)
    protected Failure failure;
    @XmlElementWrapper(name = "test-cases", required = true)
    @XmlElement(name = "test-case")
    protected List<AllureTestCaseInfo> testCases;

    /**
     * Gets the value of the uid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUid() {
        return uid;
    }

    /**
     * Sets the value of the uid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUid(String value) {
        this.uid = value;
    }

    /**
     * Gets the value of the failure property.
     * 
     * @return
     *     possible object is
     *     {@link Failure }
     *     
     */
    public Failure getFailure() {
        return failure;
    }

    /**
     * Sets the value of the failure property.
     * 
     * @param value
     *     allowed object is
     *     {@link Failure }
     *     
     */
    public void setFailure(Failure value) {
        this.failure = value;
    }

    public List<AllureTestCaseInfo> getTestCases() {
        if (testCases == null) {
            testCases = new ArrayList<AllureTestCaseInfo>();
        }
        return testCases;
    }

    public void setTestCases(List<AllureTestCaseInfo> testCases) {
        this.testCases = testCases;
    }

}
